@@ -1,6 +1,6 @@
 package Plack::Middleware::ComboLoader;
 {
-  $Plack::Middleware::ComboLoader::VERSION = '0.02';
+  $Plack::Middleware::ComboLoader::VERSION = '0.03';
 }
 use strict;
 use warnings;
@@ -17,7 +17,6 @@ use Try::Tiny;
 
 use URI::Escape 'uri_escape';
 use HTTP::Date 'time2str';
-use HTTP::Throwable::Factory qw(http_throw http_exception);
 
 # ABSTRACT: Handle combination loading and processing of on-disk resources.
 
@@ -35,6 +34,9 @@ sub call {
     my $path_info = $env->{PATH_INFO};
     $path_info =~ s/^\///;
 
+    my $req = Plack::Request->new( $env );
+    my $res = $req->new_response;
+
     if ( exists $roots->{$path_info} or exists $roots->{"/$path_info"} ) {
         my $path = $roots->{$path_info} || $roots->{"/$path_info"};
         my $config = {};
@@ -43,16 +45,15 @@ sub call {
         } else {
             $config->{path} = $path;
         }
+
         my $dir = Path::Class::Dir->new($config->{path});
         unless ( -d $dir ) {
-            http_throw( InternalServerError => {
-                message =>"Invalid root directory for `/$path_info`: $dir does not exist"
-            });
+            $res->status(500);
+            $res->body("Invalid root directory for `/$path_info`: $dir does not exist");
+            return $res->finalize;
         }
 
         my @resources = split('&', $env->{QUERY_STRING});
-        my $req = Plack::Request->new( $env );
-        my $res = $req->new_response;
         $res->status(200);
 
         my $content_type = 'plain/text';
@@ -88,9 +89,9 @@ sub call {
             my $f = $dir->file($resource);
             my $stat = $f->stat;
             unless ( defined $stat ) {
-                http_throw( BadRequest => {
-                    message => "Invalid resource requested: `$resource` is not available."
-                });
+                $res->status(400);
+                $res->content("Invalid resource requested: `$resource` is not available.");
+                return $res->finalize;
             }
 
             $seen_types{ Plack::MIME->mime_type($f->basename) || 'text/plain' } = 1;
@@ -101,9 +102,9 @@ sub call {
                 local $_ = $f;
                 try { $buffer .= $config->{processor}->($f); }
                 catch {
-                    http_throw( InternalServerError => {
-                        message => "Processing failed for `$resource`: $_"
-                    });
+                    $res->status(500);
+                    $res->body("Processing failed for `$resource`: $_");
+                    return $res->finalize;
                 };
             } else {
                 $buffer .= $f->slurp;
@@ -136,7 +137,7 @@ sub call {
         return $res->finalize;
     }
 
-    $self->app->($env);
+    return $res->finalize;
 }
 
 1;
@@ -150,7 +151,7 @@ Plack::Middleware::ComboLoader - Handle combination loading and processing of on
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -265,7 +266,7 @@ J. Shirley <j@shirley.im>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc.
+This software is copyright (c) 2012 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
